@@ -1,10 +1,19 @@
 package JSON::JOM::Plugins::YAML;
 
+use 5.010;
+use strict;
+use utf8;
+
 use JSON qw[from_json];
 use JSON::JOM::Plugins::Dumper;
+use Object::AUTHORITY;
 use YAML::Any;
 
-our $VERSION   = '0.001';
+BEGIN
+{
+	$JSON::JOM::Plugins::YAML::AUTHORITY = 'cpan:TOBYINK';
+	$JSON::JOM::Plugins::YAML::VERSION   = '0.002';
+}
 
 sub extensions
 {
@@ -47,12 +56,18 @@ L<JSON::JOM>, L<JSON::JOM::Plugins>, L<YAML::Any>.
 
 Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENCE
 
-Copyright 2010 Toby Inkster
+Copyright 2010-2011 Toby Inkster
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
+=head1 DISCLAIMER OF WARRANTIES
+
+THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
+WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
+MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+
 =cut
 
